"""This python script contain a method PrintData to print the hierarchy data structures
from the list of nth level"""

"""PrintData can be used to print data of a list which contains complex data"""
"""lstData is a argument for the method and its of type list"""
def PrintData(lstData):
    for data in lstData:
        if(isinstance(data,list)):
            PrintData(data)
        else:    
            print(data)



"""This is the setup file for create the package for HierarchyPrintData.py"""

from distutils.core import setup

setup(
        name = 'PrintHierarchyData',
        version= '1.0.0',
        py_modules = ['PrintHierarchyData'],
        author = 'Rakesh',
        author_email = 'rockyshetty2006@gmil.com',
        url = '',
        description = 'This is the test package created for learing purpose',
    )
